@@ -490,12 +490,22 @@ bool ConnectorImpl2x::compoundQueryAttachMSTGeneric(Group * target,
                         tail->bandwidth.compound_query_state.totalTimeSlots)
                     {
                         compoundQueryResult = false;
+                        if(this->bEnableLowerBppCheckForDsc)
+                        {
+                            tail->bandwidth.compound_query_state.timeslots_used_by_query -= linkConfig->slotsForPBN(base_pbn);
+                            tail->bandwidth.compound_query_state.bandwidthAllocatedForIndex &= ~(1 << compoundQueryCount);
+                        }
                         SET_DP_IMP_ERROR(pErrorCode, DP_IMP_ERROR_INSUFFICIENT_BANDWIDTH)
                     }
                 }
                 tail = (DeviceImpl*)tail->getParent();
             }
         }
+        // If the compoundQueryResult is false, we need to reset the compoundQueryLocalLinkPBN
+        if (!compoundQueryResult && this->bEnableLowerBppCheckForDsc)   
+        {
+            compoundQueryLocalLinkPBN -= slots_pbn;
+        }
     }
     else
     {
@@ -742,7 +752,20 @@ bool ConnectorImpl2x::notifyAttachBegin(Group *target, const DpModesetParams &mo
 
     // Move the group to intransistion since we are at the end of notifyAttachBegin
     intransitionGroups.insertFront(targetImpl);
+    if (dev && dev->bApplyPclkWarBug4949066 == true)
+    {
+        EvoInterface   *provider = ((EvoMainLink *)main)->getProvider();
+        NV0073_CTRL_CMD_DP_SET_PROP_FORCE_PCLK_FACTOR_PARAMS params = {0};
+        params.subDeviceInstance = provider->getSubdeviceIndex();
+        params.head = modesetParams.headIndex;
+        params.bEnable = NV_TRUE;
 
+        NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_PROP_FORCE_PCLK_FACTOR, &params, sizeof(params));
+        if (ret != NVOS_STATUS_SUCCESS)
+        {
+            DP_PRINTF(DP_ERROR, "Failed to enable the WAR for bug4949066!");
+        }
+    }
     bFromResumeToNAB = false;
     return bLinkTrainingStatus;
 }
@@ -1155,6 +1178,24 @@ void ConnectorImpl2x::notifyDetachBegin(Group *target)
     if (!target)
         target = firmwareGroup;
 
+    Device     *newDev  = target->enumDevices(0);
+    DeviceImpl *dev     = (DeviceImpl *)newDev;
+    GroupImpl  *group   = (GroupImpl*)target; 
+    
+    if (dev != NULL && dev->bApplyPclkWarBug4949066 == true)
+    {
+        EvoInterface   *provider = ((EvoMainLink *)main)->getProvider();
+        NV0073_CTRL_CMD_DP_SET_PROP_FORCE_PCLK_FACTOR_PARAMS params = {0};
+        params.subDeviceInstance = provider->getSubdeviceIndex();
+        params.head = group->headIndex;
+        params.bEnable = NV_FALSE;
+
+        NvU32 ret = provider->rmControl0073(NV0073_CTRL_CMD_DP_SET_PROP_FORCE_PCLK_FACTOR, &params, sizeof(params));
+        if (ret != NVOS_STATUS_SUCCESS)
+        {
+            DP_PRINTF(DP_ERROR, "Failed to Disable the WAR for bug4949066!");
+        }
+    }
     return ConnectorImpl::notifyDetachBegin(target);
 }
 
@@ -1713,5 +1754,10 @@ void ConnectorImpl2x::handleEdidWARs(Edid & edid, DiscoveryManager::Device & dev
             bForceHeadShutdownPerMonitor = true;
         }
     }
+
+    if (edid.WARFlags.bDisableDscMaxBppLimit)
+    {
+        bDisableDscMaxBppLimit = true;
+    }
 }
 
